delete 'Frame Hinge Assigns 02.txt'
delete 'Hinges Def 02.txt'
delete 'Hinges Def 03.txt'
delete 'Moment-curvature.txt'
delete 'Moment-rotation.txt'

clear all;
clc;
format long;


%=====================  FORMAT OF THE .TXT INPUT ========================================================================================================================================%
%  01     02      03      04    05     06        07         08       09       10      11       12       13       14   ...                            
%  ID     End      L       N     B      H        db         nz       ny       dt      st       cn       n_r      As_1 ...  As_n     f_Lv     (fc)  (fy)  (fyh)
% name  memb.end length  axial  base  height  mean diam  n.stirr  n.stirr.t diam.st  sep.st  cov nom   no.reg.  area1 ... arean     facLv    conc  long  hoops
%        [1/2]    [m]    [kN]   [mm]   [mm]     [mm]        [-]      [-]     [mm]    [mm]     [mm]      [-]     [mm2] ... [mm2]      [-]     [MPa] [MPa] [MPa]
%                        (neg)                                                               (from               (any number)     (0.005=0)  (----optional---)                     
%                                                                                        stirrup border)       (ord: from bottom)
%========================================================================================================================================================================================%



%==============================  INPUT  =================================================================================================================================================%
SAP=1;  %0: no; 1: yes

calc_teta=1;    %0: no; 1: yes
calc_curv=0;    %0: no; 1: yes

% possibility of same or different material properties
values_f=0;     % 0: same to all;    1: different for each one
% these values of fc and fy are only used if values_f=0
fc_=25/1.00+8;      % design: 1.50 and 0;         characteristic: 1.00 and 0;         medium: 1.00 and 8
fy_=500/1.00*1.26;  % design: 1.15 and 1.00;      characteristic: 1.00 and 1.00;      medium: 1.00 and 1.26 (R_omega=1.45; 1.45/1.15=1.26)

% different formulations for chord rotation
teta_y_formula=1;     % 0:without shear and fix-end;   1:with shear and fix-end   % depending on the value of calc_curv, teta_y is calculated with Fortran or with Mander, providing different values
teta_u_formula=0;     % 0:EC8 formula A.1;             1: EC8 formula A.4         % consider that formula A.4 should not be used with curvatures calculated with Mander (Biskinis, 2007). New formulations need to be implemented
%========================================================================================================================================================================================%



%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++   I: COLUMNS My   +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%


% I.1: LOAD TXT
% =======================================================================================================================================================================================%
col_M2=load('col_M2.txt');
num_el=size(col_M2,1);


% I.2: CALCULATION OF VALUES
% =======================================================================================================================================================================================%
for i=1:num_el
    
    % I.2.1: EXTRACTION OF VALUES FROM .TXT
    % -------------------------------------
    ID(i)=col_M2(i,1);
    End(i)=col_M2(i,2);
    L(i)=col_M2(i,3)*1000;
    N(i)=-col_M2(i,4); % transformation into absolute value for fortran
    B(i)=col_M2(i,5);
    H(i)=col_M2(i,6);
    db(i)=col_M2(i,7);
    nz(i)=col_M2(i,8);
    ny(i)=col_M2(i,9);
    dt(i)=col_M2(i,10);
    st(i)=col_M2(i,11);
    cn(i)=col_M2(i,12); % Same for 4 sides
    n_r(i)=col_M2(i,13);
    for j=14:14+n_r(i)-1
        As(i,j-13)=col_M2(i,j);    
    end  % Numeration of reinforcement bars by extracting only the elements different from 0
    if values_f==0
        fc(i)=fc_;
        fy(i)=fy_;
        fyh(i)=fy_;
        f_Lv=col_M2(i,end);
    elseif values_f==1
        fc(i)=col_M2(i,end-2);
        fy(i)=col_M2(i,end-1);
        fyh(i)=col_M2(i,end);
        f_Lv=col_M2(i,end-3);
    end
    
    % I.2.2: DEFINITION OF OTHER VARIABLES FROM THE BASIC ONES
    % --------------------------------------------------------
    
    % I.2.2.1: Geometric and mechanic
    Lv(i)=L(i)/2*f_Lv;
    nu(i)=N(i)*1000/(B(i)*H(i)*fc(i));
    d_prime(i)=cn(i)+dt(i)+db(i)/2; % Same for 4 sides
    Ec(i)=22000*(fc(i)/10)^0.3; % EC2 formulation
    EI1(i)=B(i)*H(i)^3/12*Ec(i);
    
    % I.2.2.2: Confinement
    As_w(i)=pi/4*nz(i)*dt(i)^2;
    ro_w(i)=As_w(i)/(B(i)*st(i));
    omega_w(i)=ro_w(i)*fyh(i)/fc(i);
    b0(i)=B(i)-2*(cn(i)+dt(i)/2);
    h0(i)=H(i)-2*(cn(i)+dt(i)/2);
    sum_bi2(i)=2*(b0(i)^2/(nz(i)-1)+h0(i)^2/(ny(i)-1));
    alfa(i)=(1-st(i)/(2*b0(i)))*(1-st(i)/(2*h0(i)))*(1-sum_bi2(i)/(6*h0(i)*b0(i))); % EC8 part 3: assuming sh=s (distance from centerline of hoops)
    amp_w(i)=25^(alfa(i)*omega_w(i));
    
        
    % I.2.3: POSITIVE BENDING MOMENT
    % ------------------------------
    
    % I.2.3.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1    
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=1:n_r(i)
            fprintf(fid1, '%g\n', As(i,j));
        end  % Filling reinforcement in normal order
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_pos=load('output.txt');
        delete output.txt
        fclose(fid1);
        % Extraction of M-curv values
        Mcr_pos(i)=M_curv_pos(1)*10^6;  % [Nmm]
        curv_cr_pos(i)=M_curv_pos(2);   % [1/mm]
        My_pos(i)=M_curv_pos(3)*10^6;   % [Nmm]
        curv_y_pos(i)=M_curv_pos(4);    % [1/mm]
        
        
    % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_pos(i),curv_cr_pos(i),My_pos(i),curv_y_pos(i),Mu_pos(i),curv_u_pos(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),As(i,1:n_r(i)),fc(i),fy(i),fyh(i));
    end
    
    
    % I.2.3.2: Calculation of teta
    if calc_teta==1
        teta_cr_pos(i)=Mcr_pos(i)*Lv(i)/(3*EI1(i));
        teta_el_pos(i)=My_pos(i)*Lv(i)/(3*EI1(i));    
        if f_Lv==0.005
            teta_y_pos(i)=0.0;
            teta_y_prime_pos(i)=0.0;
            teta_u_pos(i)=0.0002;
            teta_u_prime_pos(i)=0.0002;
            teta_ULS_pos(i)=0.0001;
            teta_ULS_prime_pos(i)=0.0001;
            % very small values for simulate quasi-elastic behaviour
        else
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_pos(i)=sum(As(i,1:n_r(i)-1))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_pos(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_pos(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_pos(i)<My_pos(i)/(1000*Lv(i));
                av_pos(i)=1;
            else
                av_pos(i)=0;
            end
            if teta_y_formula==0                              
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_pos(i)*db(i)*fy(i)/fc(i)^0.5;
            end
            teta_y_prime_pos(i)=teta_y_pos(i)-teta_el_pos(i);
            omega_pos(i)=sum(As(i,1:n_r(i)-1))*fy(i)/(B(i)*H(i)*fc(i));     % tension reinforcement: all registers except the upper one
            omega_prime_pos(i)=As(i,n_r(i))*fy(i)/(B(i)*H(i)*fc(i));        % compression reinforcement: only upper one
            if teta_u_formula==0
                teta_u_pos(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_pos(i))/max(0.01,omega_pos(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i); % no diagonal reinforcement
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_pos(i)=teta_y_pos(i)+(curv_u_pos(i)-curv_y_pos(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end 
            teta_u_prime_pos(i)=teta_u_pos(i)-teta_el_pos(i);
            teta_ULS_pos(i)=0.75*teta_u_pos(i);
            teta_ULS_prime_pos(i)=0.75*teta_u_pos(i)-teta_el_pos(i);
        end
    end
        
 
    % I.2.4: NEGATIVE BENDING MOMENT
    % ------------------------------
    
    % I.2.4.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=n_r(i):-1:1
            fprintf(fid1, '%g\n', As(i,j));
        end % Filling reinforcement in inverse order
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_neg=load('output.txt');
        delete output.txt    
        fclose(fid1);
        % Extraction of M-curv values
        Mcr_neg(i)=M_curv_neg(1)*10^6;  % [Nmm]
        curv_cr_neg(i)=M_curv_neg(2);   % [1/mm]
        My_neg(i)=M_curv_neg(3)*10^6;   % [Nmm]
        curv_y_neg(i)=M_curv_neg(4);    % [1/mm]

    
    % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_neg(i),curv_cr_neg(i),My_neg(i),curv_y_neg(i),Mu_neg(i),curv_u_neg(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),fliplr(As(i,1:n_r(i))),fc(i),fy(i),fyh(i));
    end
    
    
    % I.2.4.2: Calculation of teta
    if calc_teta==1            
        teta_cr_neg(i)=Mcr_neg(i)*Lv(i)/(3*EI1(i));
        teta_el_neg(i)=My_neg(i)*Lv(i)/(3*EI1(i));    
        if f_Lv==0.005
            teta_y_neg(i)=0.0;
            teta_y_prime_neg(i)=0.0;
            teta_u_neg(i)=0.0002;
            teta_u_prime_neg(i)=0.0002;
            teta_ULS_neg(i)=0.0001;
            teta_ULS_prime_neg(i)=0.0001;
            % very small values for simulate quasi-elastic behaviour
        else
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_neg(i)=sum(As(i,2:n_r(i)))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_neg(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_neg(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_neg(i)<My_neg(i)/(1000*Lv(i));
                av_neg(i)=1;
            else
                av_neg(i)=0;  
            end
            if teta_y_formula==0
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_neg(i)*db(i)*fy(i)/fc(i)^0.5;
            end
            teta_y_prime_neg(i)=teta_y_neg(i)-teta_el_neg(i);
            omega_neg(i)=sum(As(i,2:n_r(i)))*fy(i)/(B(i)*H(i)*fc(i));   % tension reinforcement: all registers except the lower one
            omega_prime_neg(i)=As(i,1)*fy(i)/(B(i)*H(i)*fc(i));         % compression reinforcement: only lower one
            if teta_u_formula==0
                teta_u_neg(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_neg(i))/max(0.01,omega_neg(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i);
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_neg(i)=teta_y_neg(i)+(curv_u_neg(i)-curv_y_neg(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end    
            teta_u_prime_neg(i)=teta_u_neg(i)-teta_el_neg(i);
            teta_ULS_neg(i)=0.75*teta_u_neg(i);
            teta_ULS_prime_neg(i)=0.75*teta_u_neg(i)-teta_el_neg(i);
        end
    end

    % I.2.5: SHOW COUNTING
    % --------------------
    [num2str(i), ' column M2 sections of ', num2str(num_el)]

end

   
% I.3: PRINT OF RESULTS
% =======================================================================================================================================================================================%
  
% I.3.1: M-TETA
% -------------

if calc_teta==1
    
    if SAP==0
        fid2=fopen('Moment-rotation.txt','at');
        fprintf(fid2, 'ID_End_M; Mcr+[kNm]; My+[kNm]; Theta_cr+[rad]; Theta_el+[rad]; Theta_y+[rad]; Theta_ULS+[rad]; Theta_u+[rad]; Mcr-[kNm]; My-[kNm]; Theta_cr-[rad]; Theta_el-[rad]; Theta_y-[rad]; Theta_ULS-[rad]; Theta_u-[rad]\n');
        for i=1:num_el
            fprintf(fid2, '%d_%d_2;    %g;  %g;    %g;  %g;  %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, teta_cr_pos(i), teta_el_pos(i), teta_y_pos(i), teta_ULS_pos(i), teta_u_pos(i), -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -teta_cr_neg(i), -teta_el_neg(i), -teta_y_neg(i), -teta_ULS_neg(i), -teta_u_neg(i));
        end
        fclose(fid2);
        
    elseif SAP==1
        
        fid2=fopen('Frame Hinge Assigns 02.txt','at');
        for i=1:num_el
            fprintf(fid2, '%d;%d_%d_2;RelDist;%d\n', ID(i), ID(i), End(i), End(i)-1);
        end
        fclose(fid2);
        
        fid3=fopen('Hinges Def 02.txt','at');
        for i=1:num_el
            fprintf(fid3, '%d_%d_2;Moment M2;No;Extrapolated;Moment-Rot;No;No\n', ID(i), End(i));
        end
        fclose(fid3);
        
        fid4=fopen('Hinges Def 03.txt','at');
        for i=1:num_el
            fprintf(fid4, '%d_%d_2;-E;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_u_prime_neg(i));
            fprintf(fid4, '%d_%d_2;-D;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_ULS_prime_neg(i));
            fprintf(fid4, '%d_%d_2;-C;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_y_prime_neg(i));
            fprintf(fid4, '%d_%d_2;-B;%g;0\n', ID(i), End(i), -Mcr_neg(i)/10^6);
            fprintf(fid4, '%d_%d_2;A;0;0\n', ID(i), End(i));
            fprintf(fid4, '%d_%d_2;B;%g;0\n', ID(i), End(i), Mcr_pos(i)/10^6);
            fprintf(fid4, '%d_%d_2;C;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_y_prime_pos(i));
            fprintf(fid4, '%d_%d_2;D;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_ULS_prime_pos(i));
            fprintf(fid4, '%d_%d_2;E;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_u_prime_pos(i));
        end
        fclose(fid4);
        
    end
end


% I.3.2: M-CURV
% -------------

if calc_curv==1
    fid3=fopen('Moment-curvature.txt','at');
    fprintf(fid3, 'ID_End_M; Mcr+[kNm]; My+[kNm]; Curv_cr+[1/m]; Curv_y+[1/m]; Curv_u+[1/m]; Mcr-[kNm]; My-[kNm]; Curv_cr-[1/m]; Curv_y-[1/m]; Curv_u-[1/m]\n');
    for i=1:num_el
        fprintf(fid3, '%d_%d_2;    %g;  %g;    %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, curv_cr_pos(i)*10^3, curv_y_pos(i)*10^3, curv_u_pos(i)*10^3, -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -curv_cr_neg(i)*10^3, -curv_y_neg(i)*10^3, -curv_u_neg(i)*10^3);
    end
    
    fclose(fid3);
end





%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++   II: COLUMNS Mz   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%


% II.1: LOAD TXT
% =======================================================================================================================================================================================%
col_M3=load('col_M3.txt');
num_el=size(col_M3,1);


% II.2: CALCULATION OF VALUES
% =======================================================================================================================================================================================%
for i=1:num_el
    
    % II.2.1: EXTRACTION OF VALUES FROM .TXT
    % --------------------------------------
    ID(i)=col_M3(i,1);
    End(i)=col_M3(i,2);
    L(i)=col_M3(i,3)*1000;
    N(i)=-col_M3(i,4); % transformation into absolute value for fortran
    B(i)=col_M3(i,5);
    H(i)=col_M3(i,6);
    db(i)=col_M3(i,7);
    nz(i)=col_M3(i,8);
    ny(i)=col_M3(i,9);
    dt(i)=col_M3(i,10);
    st(i)=col_M3(i,11);
    cn(i)=col_M3(i,12); % Same for 4 sides
    n_r(i)=col_M3(i,13);
    for j=14:14+n_r(i)-1
        As(i,j-13)=col_M3(i,j);    
    end  % Numeration of reinforcement bars by extracting only the elements different from 0
    if values_f==0
        fc(i)=fc_;
        fy(i)=fy_;
        fyh(i)=fy_;
        f_Lv=col_M3(i,end);
    elseif values_f==1
        fc(i)=col_M3(i,end-2);
        fy(i)=col_M3(i,end-1);
        fyh(i)=col_M3(i,end);
        f_Lv=col_M3(i,end-3);
    end
    
    % II.2.2: DEFINITION OF OTHER VARIABLES FROM THE BASIC ONES
    % ---------------------------------------------------------
    
    % II.2.2.1: Geometric and mechanic
    Lv(i)=L(i)/2*f_Lv;
    nu(i)=N(i)*1000/(B(i)*H(i)*fc(i));
    d_prime(i)=cn(i)+dt(i)+db(i)/2; % Same for 4 sides
    Ec(i)=22000*(fc(i)/10)^0.3; % EC2 formulation
    EI1(i)=B(i)*H(i)^3/12*Ec(i);
    
    % II.2.2.2: Confinement
    As_w(i)=pi/4*nz(i)*dt(i)^2;
    ro_w(i)=As_w(i)/(B(i)*st(i));
    omega_w(i)=ro_w(i)*fyh(i)/fc(i);
    b0(i)=B(i)-2*(cn(i)+dt(i)/2);
    h0(i)=H(i)-2*(cn(i)+dt(i)/2);
    sum_bi2(i)=2*(b0(i)^2/(nz(i)-1)+h0(i)^2/(ny(i)-1));
    alfa(i)=(1-st(i)/(2*b0(i)))*(1-st(i)/(2*h0(i)))*(1-sum_bi2(i)/(6*h0(i)*b0(i))); % EC8 part 3: assuming sh=s (distance from centerline of hoops)
    amp_w(i)=25^(alfa(i)*omega_w(i));
    
        
    % II.2.3: POSITIVE BENDING MOMENT
    % -------------------------------
    
    % II.2.3.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1    
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=1:n_r(i)
            fprintf(fid1, '%g\n', As(i,j));
        end  % Filling reinforcement in normal order
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_pos=load('output.txt');
        delete output.txt
        fclose(fid1);
        % Extraction of M-curv values
        Mcr_pos(i)=M_curv_pos(1)*10^6;  % [Nmm]
        curv_cr_pos(i)=M_curv_pos(2);   % [1/mm]
        My_pos(i)=M_curv_pos(3)*10^6;   % [Nmm]
        curv_y_pos(i)=M_curv_pos(4);    % [1/mm]
        
        
    % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_pos(i),curv_cr_pos(i),My_pos(i),curv_y_pos(i),Mu_pos(i),curv_u_pos(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),As(i,1:n_r(i)),fc(i),fy(i),fyh(i));
    end
    
    
    % II.2.3.2: Calculation of teta
    if calc_teta==1
        teta_cr_pos(i)=Mcr_pos(i)*Lv(i)/(3*EI1(i));
        teta_el_pos(i)=My_pos(i)*Lv(i)/(3*EI1(i));    
        if f_Lv==0.005
            teta_y_pos(i)=0.0;
            teta_y_prime_pos(i)=0.0;
            teta_u_pos(i)=0.0002;
            teta_u_prime_pos(i)=0.0002;
            teta_ULS_pos(i)=0.0001;
            teta_ULS_prime_pos(i)=0.0001;
            % very small values for simulate quasi-elastic behaviour
        else
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_pos(i)=sum(As(i,1:n_r(i)-1))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_pos(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_pos(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_pos(i)<My_pos(i)/(1000*Lv(i));
                av_pos(i)=1;
            else
                av_pos(i)=0;
            end
            if teta_y_formula==0                              
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_pos(i)*db(i)*fy(i)/fc(i)^0.5;
            end
            teta_y_prime_pos(i)=teta_y_pos(i)-teta_el_pos(i);
            omega_pos(i)=sum(As(i,1:n_r(i)-1))*fy(i)/(B(i)*H(i)*fc(i));     % tension reinforcement: all registers except the upper one
            omega_prime_pos(i)=As(i,n_r(i))*fy(i)/(B(i)*H(i)*fc(i));        % compression reinforcement: only upper one
            if teta_u_formula==0
                teta_u_pos(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_pos(i))/max(0.01,omega_pos(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i); % no diagonal reinforcement
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_pos(i)=teta_y_pos(i)+(curv_u_pos(i)-curv_y_pos(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end 
            teta_u_prime_pos(i)=teta_u_pos(i)-teta_el_pos(i);
            teta_ULS_pos(i)=0.75*teta_u_pos(i);
            teta_ULS_prime_pos(i)=0.75*teta_u_pos(i)-teta_el_pos(i);
        end
    end
        
 
    % II.2.4: NEGATIVE BENDING MOMENT
    % -------------------------------
    
    % II.2.4.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=n_r(i):-1:1
            fprintf(fid1, '%g\n', As(i,j));
        end % Filling reinforcement in inverse order
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_neg=load('output.txt');
        delete output.txt    
        fclose(fid1);
        % Extraction of M-curv values
        Mcr_neg(i)=M_curv_neg(1)*10^6;  % [Nmm]
        curv_cr_neg(i)=M_curv_neg(2);   % [1/mm]
        My_neg(i)=M_curv_neg(3)*10^6;   % [Nmm]
        curv_y_neg(i)=M_curv_neg(4);    % [1/mm]

    
    % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_neg(i),curv_cr_neg(i),My_neg(i),curv_y_neg(i),Mu_neg(i),curv_u_neg(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),fliplr(As(i,1:n_r(i))),fc(i),fy(i),fyh(i));
    end
    
    
    % II.2.4.2: Calculation of teta
    if calc_teta==1            
        teta_cr_neg(i)=Mcr_neg(i)*Lv(i)/(3*EI1(i));
        teta_el_neg(i)=My_neg(i)*Lv(i)/(3*EI1(i));    
        if f_Lv==0.005
            teta_y_neg(i)=0.0;
            teta_y_prime_neg(i)=0.0;
            teta_u_neg(i)=0.0002;
            teta_u_prime_neg(i)=0.0002;
            teta_ULS_neg(i)=0.0001;
            teta_ULS_prime_neg(i)=0.0001;
            % very small values for simulate quasi-elastic behaviour
        else
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_neg(i)=sum(As(i,2:n_r(i)))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_neg(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_neg(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_neg(i)<My_neg(i)/(1000*Lv(i));
                av_neg(i)=1;
            else
                av_neg(i)=0;  
            end
            if teta_y_formula==0
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_neg(i)*db(i)*fy(i)/fc(i)^0.5;
            end
            teta_y_prime_neg(i)=teta_y_neg(i)-teta_el_neg(i);
            omega_neg(i)=sum(As(i,2:n_r(i)))*fy(i)/(B(i)*H(i)*fc(i));   % tension reinforcement: all registers except the lower one
            omega_prime_neg(i)=As(i,1)*fy(i)/(B(i)*H(i)*fc(i));         % compression reinforcement: only lower one
            if teta_u_formula==0
                teta_u_neg(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_neg(i))/max(0.01,omega_neg(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i);
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_neg(i)=teta_y_neg(i)+(curv_u_neg(i)-curv_y_neg(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end    
            teta_u_prime_neg(i)=teta_u_neg(i)-teta_el_neg(i);
            teta_ULS_neg(i)=0.75*teta_u_neg(i);
            teta_ULS_prime_neg(i)=0.75*teta_u_neg(i)-teta_el_neg(i);
        end
    end

    % II.2.5: SHOW COUNTING
    % ---------------------
    [num2str(i), ' column M3 sections of ', num2str(num_el)]

end

   
% II.3: PRINT OF RESULTS
% =======================================================================================================================================================================================%
  
% II.3.1: M-TETA
% --------------

if calc_teta==1
    
    if SAP==0
        fid2=fopen('Moment-rotation.txt','at');
        for i=1:num_el
            fprintf(fid2, '%d_%d_3;    %g;  %g;    %g;  %g;  %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, teta_cr_pos(i), teta_el_pos(i), teta_y_pos(i), teta_ULS_pos(i), teta_u_pos(i), -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -teta_cr_neg(i), -teta_el_neg(i), -teta_y_neg(i), -teta_ULS_neg(i), -teta_u_neg(i));
        end
        fclose(fid2);
        
        
    elseif SAP==1
        
        fid2=fopen('Frame Hinge Assigns 02.txt','at');
        for i=1:num_el
            fprintf(fid2, '%d;%d_%d_3;RelDist;%d\n', ID(i), ID(i), End(i), End(i)-1);
        end
        fclose(fid2);
        
        fid3=fopen('Hinges Def 02.txt','at');
        for i=1:num_el
            fprintf(fid3, '%d_%d_3;Moment M3;No;Extrapolated;Moment-Rot;No;No\n', ID(i), End(i));
        end
        fclose(fid3);
        
        fid4=fopen('Hinges Def 03.txt','at');
        for i=1:num_el
            fprintf(fid4, '%d_%d_3;-E;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_u_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-D;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_ULS_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-C;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_y_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-B;%g;0\n', ID(i), End(i), -Mcr_neg(i)/10^6);
            fprintf(fid4, '%d_%d_3;A;0;0\n', ID(i), End(i));
            fprintf(fid4, '%d_%d_3;B;%g;0\n', ID(i), End(i), Mcr_pos(i)/10^6);
            fprintf(fid4, '%d_%d_3;C;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_y_prime_pos(i));
            fprintf(fid4, '%d_%d_3;D;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_ULS_prime_pos(i));
            fprintf(fid4, '%d_%d_3;E;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_u_prime_pos(i));
        end
        fclose(fid4);
 
    end
end


% II.3.2: M-CURV
% --------------
if calc_curv==1
    fid3=fopen('Moment-curvature.txt','at');
    for i=1:num_el
        fprintf(fid3, '%d_%d_3;    %g;  %g;    %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, curv_cr_pos(i)*10^3, curv_y_pos(i)*10^3, curv_u_pos(i)*10^3, -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -curv_cr_neg(i)*10^3, -curv_y_neg(i)*10^3, -curv_u_neg(i)*10^3);
    end
    
    fclose(fid3);
end













%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++   III: BEAMS   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%


% III.1: LOAD TXT
% =======================================================================================================================================================================================%
bea=load('bea_M3.txt');
num_el=size(bea,1);

% III.2: CALCULATION OF VALUES
% =======================================================================================================================================================================================%
for i=1:num_el

    % III.2.1: EXTRACTION OF VALUES FROM .TXT
    % ---------------------------------------
    ID(i)=bea(i,1);
    End(i)=bea(i,2);
    L(i)=bea(i,3)*1000;
    N(i)=-bea(i,4); % transformation into absolute value for fortran
    B(i)=bea(i,5);
    H(i)=bea(i,6);
    db(i)=bea(i,7);
    nz(i)=bea(i,8);
    ny(i)=bea(i,9);
    dt(i)=bea(i,10);
    st(i)=bea(i,11);
    cn(i)=bea(i,12); % Same for 4 sides
    n_r(i)=bea(i,13);
    for j=14:14+n_r(i)-1
        As(i,j-13)=bea(i,j);
    end  % Numeration of reinforcement bars by extracting only the elements different from 0
    if values_f==0
        fc(i)=fc_;
        fy(i)=fy_;
        fyh(i)=fy_;
        f_Lv=bea(i,end);
    elseif values_f==1
        fc(i)=bea(i,end-2);
        fy(i)=bea(i,end-1);
        fyh(i)=bea(i,end);
        f_Lv=bea(i,end-3);
    end
    
    % III.2.2: DEFINITION OF OTHER VARIABLES FROM THE BASIC ONES
    % ----------------------------------------------------------
    
    % III.2.2.1: Geometric and mechanic
    Lv(i)=L(i)/2*f_Lv;
    nu(i)=N(i)*1000/(B(i)*H(i)*fc(i));
    d_prime(i)=cn(i)+dt(i)+db(i)/2;
    Ec(i)=22000*(fc(i)/10)^0.3;
    EI1(i)=B(i)*H(i)^3/12*Ec(i);
    
    % III.2.2.2: Confinement
    As_w(i)=pi/4*nz(i)*dt(i)^2;
    ro_w(i)=As_w(i)/(B(i)*st(i));
    omega_w(i)=ro_w(i)*fyh(i)/fc(i);
    b0(i)=B(i)-2*(cn(i)+dt(i)/2);
    h0(i)=H(i)-2*(cn(i)+dt(i)/2);
    sum_bi2(i)=2*(b0(i)^2/(nz(i)-1)+h0(i)^2/(ny(i)-1));
    alfa(i)=(1-st(i)/(2*b0(i)))*(1-st(i)/(2*h0(i)))*(1-sum_bi2(i)/(6*h0(i)*b0(i)));
    amp_w(i)=25^(alfa(i)*omega_w(i));
    
    
    
    % III.2.3: POSITIVE BENDING MOMENT
    % --------------------------------
    
    % III.2.3.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=1:n_r(i)
            fprintf(fid1, '%g\n', As(i,j));
        end  % Filling reinforcement in normal order    
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_pos=load('output.txt');
        delete output.txt
        fclose(fid1);    
        % Extraction of M-curv values
        Mcr_pos(i)=M_curv_pos(1)*10^6;  % [Nmm]
        curv_cr_pos(i)=M_curv_pos(2);   % [1/mm]
        My_pos(i)=M_curv_pos(3)*10^6;   % [Nmm]
        curv_y_pos(i)=M_curv_pos(4);    % [1/mm]
    
   % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_pos(i),curv_cr_pos(i),My_pos(i),curv_y_pos(i),Mu_pos(i),curv_u_pos(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),As(i,1:n_r(i)),fc(i),fy(i),fyh(i));
    end
    
    
    % III.2.3.2: Calculation of teta
    if calc_teta==1   
        teta_el_pos(i)=My_pos(i)*Lv(i)/(3*EI1(i));
        teta_cr_pos(i)=Mcr_pos(i)*Lv(i)/(3*EI1(i));
        if f_Lv==0.005
            teta_y_pos(i)=0.0;
            teta_y_prime_pos(i)=0.0;
            teta_u_pos(i)=0.0002;
            teta_u_prime_pos(i)=0.0002;
            teta_ULS_pos(i)=0.0001;
            teta_ULS_prime_pos(i)=0.0001;        
            % very small values for simulate quasi-elastic behaviour
        else
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_pos(i)=sum(As(i,1:n_r(i)-1))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_pos(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_pos(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_pos(i)<My_pos(i)/(1000*Lv(i));
                av_pos(i)=1;
            else
                av_pos(i)=0;
            end
            if teta_y_formula==0                              
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_pos(i)=curv_y_pos(i)*(Lv(i)+av_pos(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_pos(i)*db(i)*fy(i)/fc(i)^0.5;
            end
            teta_y_prime_pos(i)=teta_y_pos(i)-teta_el_pos(i);
            omega_pos(i)=sum(As(i,1:n_r(i)-1))*fy(i)/(B(i)*H(i)*fc(i));     % tension reinforcement: all registers except the upper one
            omega_prime_pos(i)=As(i,n_r(i))*fy(i)/(B(i)*H(i)*fc(i));        % compression reinforcement: only upper one
            if teta_u_formula==0
                teta_u_pos(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_pos(i))/max(0.01,omega_pos(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i);
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_pos(i)=teta_y_pos(i)+(curv_u_pos(i)-curv_y_pos(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end
            teta_u_prime_pos(i)=teta_u_pos(i)-teta_el_pos(i);
            teta_ULS_pos(i)=0.75*teta_u_pos(i);
            teta_ULS_prime_pos(i)=0.75*teta_u_pos(i)-teta_el_pos(i);            
        end
    end
        
    
    
    % III.2.4: NEGATIVE BENDING MOMENT
    % --------------------------------
    
    % III.2.4.1: Calculation of M-curv
    
    % Case Fortran (only teta)
    if calc_curv==0&calc_teta==1
        % Filling input for fortran
        fid1=fopen('input_2.txt','wt');
        fprintf(fid1, '%g\n', N(i));
        fprintf(fid1, '%g\n', fc(i));
        fprintf(fid1, '1\n');
        fprintf(fid1, '%g\n', fy(i));
        fprintf(fid1, '%g\n', B(i));
        fprintf(fid1, '%g\n', H(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', d_prime(i));
        fprintf(fid1, '%g\n', n_r(i));
        for j=n_r(i):-1:1
            fprintf(fid1, '%g\n', As(i,j));
        end % Filling reinforcement in inverse order    
        % Carrying out fortran Moment-Curvature
        ! mom_curv_2_cr-y
        M_curv_neg=load('output.txt');
        delete output.txt
        fclose(fid1);    
        % Extraction of M-curv values
        Mcr_neg(i)=M_curv_neg(1)*10^6;  % [Nmm]
        curv_cr_neg(i)=M_curv_neg(2);   % [1/mm]
        My_neg(i)=M_curv_neg(3)*10^6;   % [Nmm]    
        curv_y_neg(i)=M_curv_neg(4);    % [1/mm]
    
    % Case Mander (curvatures needed)
    elseif calc_curv==1|(calc_teta==1&teta_u_formula==1) % if explicit curvatures or teta_u semi-empirical are needed
        [Mcr_neg(i),curv_cr_neg(i),My_neg(i),curv_y_neg(i),Mu_neg(i),curv_u_neg(i)]=M_curv_Mander(N(i),B(i),H(i),db(i),nz(i),ny(i),dt(i),st(i),sum_bi2(i),d_prime(i),fliplr(As(i,1:n_r(i))),fc(i),fy(i),fyh(i));
    end
    
    
    % III.2.4.5: Calculation of teta
    if calc_teta==1
        teta_cr_neg(i)=Mcr_neg(i)*Lv(i)/(3*EI1(i));
        teta_el_neg(i)=My_neg(i)*Lv(i)/(3*EI1(i));
        if f_Lv==0.005
            teta_y_neg(i)=0.0;
            teta_y_prime_neg(i)=0.0;
            teta_u_neg(i)=0.0002;
            teta_u_prime_neg(i)=0.0002;
            teta_ULS_neg(i)=0.0001;
            teta_ULS_prime_neg(i)=0.0001;        
            % very small values for simulate quasi-elastic behaviour
        else            
            d(i)=H(i)-d_prime(i);
            z(i)=d(i)-d_prime(i);
            ro_neg(i)=sum(As(i,2:n_r(i)))/(B(i)*H(i));
            k(i)=min(1+(200/d(i))^0.5,2);
            Vcr_neg(i)=B(i)*d(i)*(max(0.18*k(i)*(100*min(0.02,ro_neg(i))*fc(i))^(1/3),0.035*k(i)^1.5*fc(i)^0.5)+0.15*fc(i)*min(nu(i),0.2))/1000;
            if Vcr_neg(i)<My_neg(i)/(1000*Lv(i));
                av_neg(i)=1;
            else
                av_neg(i)=0;  
            end
            if teta_y_formula==0
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3;
            elseif teta_y_formula==1
                teta_y_neg(i)=curv_y_neg(i)*(Lv(i)+av_neg(i)*z(i))/3 + 0.0013*(1+1.5*H(i)/(Lv(i))) + 0.13*curv_y_neg(i)*db(i)*fy(i)/fc(i)^0.5;
            end            
            teta_y_prime_neg(i)=teta_y_neg(i)-teta_el_neg(i);
            omega_neg(i)=sum(As(i,2:n_r(i)))*fy(i)/(B(i)*H(i)*fc(i));   % tension reinforcement: all registers except the lower one
            omega_prime_neg(i)=As(i,1)*fy(i)/(B(i)*H(i)*fc(i));         % compression reinforcement: only lower one
            if teta_u_formula==0
                teta_u_neg(i)=0.016*0.3^nu(i)*(max(0.01,omega_prime_neg(i))/max(0.01,omega_neg(i))*fc(i))^0.225*(Lv(i)/(H(i)))^0.35*amp_w(i);
            elseif teta_u_formula==1
                L_pl(i)=0.1*Lv(i)+0.17*H(i)+0.24*db(i)*fy(i)/fc(i)^0.5; % assuming material constitutive models of EC2
                teta_u_neg(i)=teta_y_neg(i)+(curv_u_neg(i)-curv_y_neg(i))*L_pl(i)*(1-0.5*L_pl(i)/Lv(i));
            end  
            teta_u_prime_neg(i)=teta_u_neg(i)-teta_el_neg(i);
            teta_ULS_neg(i)=0.75*teta_u_neg(i);
            teta_ULS_prime_neg(i)=0.75*teta_u_neg(i)-teta_el_neg(i);
        end
    end
    
    % III.2.5: SHOW COUNTING
    % ----------------------
    [num2str(i), ' beam M3 sections of ', num2str(num_el)]
    
end

% III.3: PRINT OF RESULTS
% =======================================================================================================================================================================================%

% III.3.1: M-TETA
% ---------------

if calc_teta==1
    
    if SAP==0
        fid2=fopen('Moment-rotation.txt','at');
        for i=1:num_el
            fprintf(fid2, '%d_%d_3;    %g;  %g;    %g;  %g;  %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, teta_cr_pos(i), teta_el_pos(i), teta_y_pos(i), teta_ULS_pos(i), teta_u_pos(i), -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -teta_cr_neg(i), -teta_el_neg(i), -teta_y_neg(i), -teta_ULS_neg(i), -teta_u_neg(i));
        end
        fclose(fid2);
        
    elseif SAP==1
        
        fid2=fopen('Frame Hinge Assigns 02.txt','at');
        for i=1:num_el
            fprintf(fid2, '%d;%d_%d_3;RelDist;%d\n', ID(i), ID(i), End(i), End(i)-1);
        end
        fclose(fid2);
        
        fid3=fopen('Hinges Def 02.txt','at');
        for i=1:num_el
            fprintf(fid3, '%d_%d_3;Moment M3;No;Extrapolated;Moment-Rot;No;No\n', ID(i), End(i));
        end
        fclose(fid3);
        
        fid4=fopen('Hinges Def 03.txt','at');
        for i=1:num_el
            fprintf(fid4, '%d_%d_3;-E;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_u_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-D;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_ULS_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-C;%g;%g\n', ID(i), End(i), -My_neg(i)/10^6, -teta_y_prime_neg(i));
            fprintf(fid4, '%d_%d_3;-B;%g;0\n', ID(i), End(i), -Mcr_neg(i)/10^6);
            fprintf(fid4, '%d_%d_3;A;0;0\n', ID(i), End(i));
            fprintf(fid4, '%d_%d_3;B;%g;0\n', ID(i), End(i), Mcr_pos(i)/10^6);
            fprintf(fid4, '%d_%d_3;C;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_y_prime_pos(i));
            fprintf(fid4, '%d_%d_3;D;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_ULS_prime_pos(i));
            fprintf(fid4, '%d_%d_3;E;%g;%g\n', ID(i), End(i), My_pos(i)/10^6, teta_u_prime_pos(i));
        end
        fclose(fid4);
        
    end
end


% III.3.2: M-CURV
% ---------------

if calc_curv==1
    fid3=fopen('Moment-curvature.txt','at');
    for i=1:num_el
        fprintf(fid3, '%d_%d_3;    %g;  %g;    %g;  %g;  %g;      %g;  %g;    %g;  %g;  %g\n', ID(i), End(i), Mcr_pos(i)/10^6, My_pos(i)/10^6, curv_cr_pos(i)*10^3, curv_y_pos(i)*10^3, curv_u_pos(i)*10^3, -Mcr_neg(i)/10^6, -My_neg(i)/10^6, -curv_cr_neg(i)*10^3, -curv_y_neg(i)*10^3, -curv_u_neg(i)*10^3);
    end
    
    fclose(fid3);
end






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Deleting rubish (if the program gets aborted, some rubish should be deleted by hand)
if calc_curv==0&calc_teta==1
    delete input_2.txt
    delete mom_curv.txt
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
